%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Investment Judgment Advisor
%%% Programed by Jhiin Joo specifically for MAC users
%%% March 3, 2009
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function varargout = ShowResults_Third(varargin)
global counter Xs Ws
% SHOWRESULTS_THIRD M-file for ShowResults_Third.fig
%      SHOWRESULTS_THIRD, by itself, creates a new SHOWRESULTS_THIRD or
%      raises the existing
%      singleton*.
%
%      H = SHOWRESULTS_THIRD returns the handle to a new SHOWRESULTS_THIRD or the handle to
%      the existing singleton*.
%
%      SHOWRESULTS_THIRD('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in SHOWRESULTS_THIRD.M with the given input arguments.
%
%      SHOWRESULTS_THIRD('Property','Value',...) creates a new SHOWRESULTS_THIRD or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before ShowResults_Third_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to ShowResults_Third_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Copyright 2002-2003 The MathWorks, Inc.

% Edit the above text to modify the response to help ShowResults_Third

% Last Modified by GUIDE v2.5 20-Apr-2009 11:53:39

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @ShowResults_Third_OpeningFcn, ...
                   'gui_OutputFcn',  @ShowResults_Third_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT




% --- Executes just before ShowResults_Third is made visible.
function ShowResults_Third_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    
% structure with handles and user data (see GUIDATA)
% varargin   command line arguments to ShowResults_Third (see VARARGIN)

global Xs Ws MFsf_nega WhichInv
global counter Cs S
global xxs xxl xxr a
global xxsm xxsl xxsr 
global popupmenu61
global XS1 WS1 XXS1 XXL1 XXR1 XXSM1 XXSL1 XXSR1
global ling1_11 ling1_12 ling1_13 ling1_14
global ling1_21 ling1_22 ling1_23 ling1_24
global ling1_31 ling1_32 ling1_33 ling1_34
global ling1_41 ling1_42 ling1_43 ling1_44
global ling1_51 ling1_52 ling1_53 ling1_54
global ling1_61 ling1_62 ling1_63 ling1_64
global rank1_1 rank1_2 rank1_3 rank1_4 rank1_5
global cen1_1 cen1_2 cen1_3 cen1_4 cen1_5
global sim1_11 sim1_12 sim1_13 sim1_14 sim1_15
global sim1_21 sim1_22 sim1_23 sim1_24 sim1_25
global sim1_31 sim1_32 sim1_33 sim1_34 sim1_35
global sim1_41 sim1_42 sim1_43 sim1_44 sim1_45
global sim1_51 sim1_52 sim1_53 sim1_54 sim1_55

global XS2 WS2 XXS2 XXL2 XXR2 XXSM2 XXSL2 XXSR2
global ling2_11 ling2_12 ling2_13 ling2_14
global ling2_21 ling2_22 ling2_23 ling2_24
global ling2_31 ling2_32 ling2_33 ling2_34
global ling2_41 ling2_42 ling2_43 ling2_44
global ling2_51 ling2_52 ling2_53 ling2_54
global ling2_61 ling2_62 ling2_63 ling2_64
global rank2_1 rank2_2 rank2_3 rank2_4 rank2_5
global cen2_1 cen2_2 cen2_3 cen2_4 cen2_5
global sim2_11 sim2_12 sim2_13 sim2_14 sim2_15
global sim2_21 sim2_22 sim2_23 sim2_24 sim2_25
global sim2_31 sim2_32 sim2_33 sim2_34 sim2_35
global sim2_41 sim2_42 sim2_43 sim2_44 sim2_45
global sim2_51 sim2_52 sim2_53 sim2_54 sim2_55

global XS3 WS3 XXS3 XXL3 XXR3 XXSM3 XXSL3 XXSR3
global ling3_11 ling3_12 ling3_13 ling3_14
global ling3_21 ling3_22 ling3_23 ling3_24
global ling3_31 ling3_32 ling3_33 ling3_34
global ling3_41 ling3_42 ling3_43 ling3_44
global ling3_51 ling3_52 ling3_53 ling3_54
global ling3_61 ling3_62 ling3_63 ling3_64
global rank3_1 rank3_2 rank3_3 rank3_4 rank3_5
global cen3_1 cen3_2 cen3_3 cen3_4 cen3_5
global sim3_11 sim3_12 sim3_13 sim3_14 sim3_15
global sim3_21 sim3_22 sim3_23 sim3_24 sim3_25
global sim3_31 sim3_32 sim3_33 sim3_34 sim3_35
global sim3_41 sim3_42 sim3_43 sim3_44 sim3_45
global sim3_51 sim3_52 sim3_53 sim3_54 sim3_55
global ppmenu11 ppmenu12 ppmenu13 ppmenu14 ppmenu21 ppmenu22 ppmenu23 ppmenu24
global ppmenu31 ppmenu32 ppmenu33 ppmenu34 ppmenu41 ppmenu42 ppmenu43 ppmenu44
global ppmenu51 ppmenu52 ppmenu53 ppmenu54 ppmenu61 ppmenu62 ppmenu63 ppmenu64 

global ppmenu11 ppmenu12 ppmenu13 ppmenu14 ppmenu21 ppmenu22 ppmenu23 ppmenu24 
global ppmenu31 ppmenu32 ppmenu33 ppmenu34 ppmenu41 ppmenu42 ppmenu43 ppmenu44 
global ppmenu51 ppmenu52 ppmenu53 ppmenu54 ppmenu61 ppmenu62 ppmenu63 ppmenu64 
global wordsf wordss words_w MFsf MFss MFs_w
global ppmenu11string ppmenu14string ppmenu61string
global Special
global templet

%% Previous Parameters (-1th Set)
global XSp WSp XXSp XXLp XXRp XXSMp XXSLp XXSRp
global lingp_11 lingp_12 lingp_13 lingp_14
global lingp_21 lingp_22 lingp_23 lingp_24
global lingp_31 lingp_32 lingp_33 lingp_34
global lingp_41 lingp_42 lingp_43 lingp_44
global lingp_51 lingp_52 lingp_53 lingp_54
global lingp_61 lingp_62 lingp_63 lingp_64
global rankp_1 rankp_2 rankp_3 rankp_4 rankp_5
global cenp_1 cenp_2 cenp_3 cenp_4 cenp_5
global simp_11 simp_12 simp_13 simp_14 simp_15
global simp_21 simp_22 simp_23 simp_24 simp_25
global simp_31 simp_32 simp_33 simp_34 simp_35
global simp_41 simp_42 simp_43 simp_44 simp_45
global simp_51 simp_52 simp_53 simp_54 simp_55

% set(handles.text1,'Visible','off');
% set(handles.text13,'Visible','off');
% set(handles.text24,'Visible','off');
clear whichInv

if templet~=1
    set(handles.pushbutton1,'Visible','off');
    set(handles.pushbutton2,'Visible','off');
    if counter==3
            set(handles.text1,'String',['FIRST RESULT'],'fontweight','bold');
            set(handles.text13,'String',['SECOND RESULT'],'fontweight','bold');
            set(handles.text24,'String',['THIRD RESULT'],'fontweight','bold');    
    elseif counter==4
            set(handles.text1,'String',['SECOND RESULT'],'fontweight','bold');
            set(handles.text13,'String',['THIRD RESULT'],'fontweight','bold');
            set(handles.text24,'String',['FORTH RESULT'],'fontweight','bold');  
            
    elseif counter==5
            set(handles.text1,'String',['THIRD RESULT'],'fontweight','bold');
            set(handles.text13,'String',['FORTH RESULT'],'fontweight','bold');
            set(handles.text24,'String',['FIFTH RESULT'],'fontweight','bold');  
    elseif counter==6
            set(handles.text1,'String',['FORTH RESULT'],'fontweight','bold');
            set(handles.text13,'String',['FIFTH RESULT'],'fontweight','bold');
            set(handles.text24,'String',['SIXTH RESULT'],'fontweight','bold');  
    elseif counter==7
            set(handles.text1,'String',['FIFTH RESULT'],'fontweight','bold');
            set(handles.text13,'String',['SIXTH RESULT'],'fontweight','bold');
            set(handles.text24,'String',['SEVENTH RESULT'],'fontweight','bold');  
    elseif counter==8
            set(handles.text1,'String',['SIXTH RESULT'],'fontweight','bold');
            set(handles.text13,'String',['SEVENTH RESULT'],'fontweight','bold');
            set(handles.text24,'String',['EIGHTH RESULT'],'fontweight','bold');  
    elseif counter==9
            set(handles.text1,'String',['SEVENTH RESULT'],'fontweight','bold');
            set(handles.text13,'String',['EIGHTH RESULT'],'fontweight','bold');
            set(handles.text24,'String',['NINTH RESULT'],'fontweight','bold'); 
    elseif counter==10
            set(handles.text1,'String',['EIGHTH RESULT'],'fontweight','bold');
            set(handles.text13,'String',['NINTH RESULT'],'fontweight','bold');
            set(handles.text24,'String',['TENTH RESULT'],'fontweight','bold'); 
    end  
elseif templet==1
    set(handles.text1,'String',['CONSERVATIVE'],'fontweight','bold');
    set(handles.text13,'String',['INBETWEEN'],'fontweight','bold');
    set(handles.text24,'String',['SPECULATIVE'],'fontweight','bold');   
end

set(handles.text1,'Visible','on');
set(handles.text13,'Visible','on');
set(handles.text24,'Visible','on');

global XS1 XS2 XS3 WS1 WS2 WS3

if templet==1 %% TEMPLET
    %% Conservative
    prepareDataFLIA11; 
    Xs=[8 6 4 4;7 7 6 5;4 5 5 4;6 6 7 4;1 4 6 5];
    Ws=[4 3 2 3];
    
    %% 
  
    executeLWA_FLIA1;
    Results_counter1;
    
    %% Save Parameters for CONSERVATIVE
    SaveParameters1;
    

    %% Inbetween
    prepareDataFLIA11; 
    Xs=[7 7 6 3;5 5 7 7;3 4 4 3;5 5 7 5;3 3 3 4];
    Ws=[3 3 2 3];
    
    
   
    executeLWA_FLIA1;
    Results_counter2;
    
    SaveParameters2;


    %% Speculative
    prepareDataFLIA11; 

    Xs=[5 5 8 6;6 5 7 5;2 3 2 3;4 6 6 5;1 4 2 1];
    Ws=[1 2 2 2];
    
    
    executeLWA_FLIA1;
    Results_counter3;
    SaveParameters3;

else
    
    ShowPrevParam1; %% First Set
    ShowPrevParam2; %% Second Set
    
    Special;
    Results_counter3;

    SaveParameters3;
%     close(IJA);
end
    

    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%55
% Choose default command line output for ShowResults_Third
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes ShowResults_Third wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = ShowResults_Third_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;



function edit1_11_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_11 as text
%        str2double(get(hObject,'String')) returns contents of edit1_11 as a double


% --- Executes during object creation, after setting all properties.
function edit1_11_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_12_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_12 as text
%        str2double(get(hObject,'String')) returns contents of edit1_12 as a double


% --- Executes during object creation, after setting all properties.
function edit1_12_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_13_Callback(hObject, eventdata, handles)
% hObject    handle to edit3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3 as text
%        str2double(get(hObject,'String')) returns contents of edit3 as a double


% --- Executes during object creation, after setting all properties.
function edit1_13_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_14_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_14 as text
%        str2double(get(hObject,'String')) returns contents of edit1_14 as a double


% --- Executes during object creation, after setting all properties.
function edit1_14_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit1_21_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_21 as text
%        str2double(get(hObject,'String')) returns contents of edit1_21 as a double


% --- Executes during object creation, after setting all properties.
function edit1_21_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit1_22_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_21 as text
%        str2double(get(hObject,'String')) returns contents of edit1_21 as a double


% --- Executes during object creation, after setting all properties.
function edit1_22_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit1_23_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_23 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_23 as text
%        str2double(get(hObject,'String')) returns contents of edit1_23 as a double


% --- Executes during object creation, after setting all properties.
function edit1_23_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_23 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_24_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_24 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_24 as text
%        str2double(get(hObject,'String')) returns contents of edit1_24 as a double


% --- Executes during object creation, after setting all properties.
function edit1_24_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_24 (see GCBO)
% % eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit1_31_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_31 as text
%        str2double(get(hObject,'String')) returns contents of edit1_31 as a double


% --- Executes during object creation, after setting all properties.
function edit1_31_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function edit1_32_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_34 as text
%        str2double(get(hObject,'String')) returns contents of edit1_34 as a double


% --- Executes during object creation, after setting all properties.
function edit1_32_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function edit1_33_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_33 as text
%        str2double(get(hObject,'String')) returns contents of edit1_33 as a double


% --- Executes during object creation, after setting all properties.
function edit1_33_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_34_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_34 as text
%        str2double(get(hObject,'String')) returns contents of edit1_34 as a double


% --- Executes during object creation, after setting all properties.
function edit1_34_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit1_41_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_41 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_41 as text
%        str2double(get(hObject,'String')) returns contents of edit1_41 as a double


% --- Executes during object creation, after setting all properties.
function edit1_41_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_41 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit1_42_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_44 as text
%        str2double(get(hObject,'String')) returns contents of edit1_44 as a double


% --- Executes during object creation, after setting all properties.
function edit1_42_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit1_43_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_43 as text
%        str2double(get(hObject,'String')) returns contents of edit1_43 as a double


% --- Executes during object creation, after setting all properties.
function edit1_43_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit1_44_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_44 as text
%        str2double(get(hObject,'String')) returns contents of edit1_44 as a double


% --- Executes during object creation, after setting all properties.
function edit1_44_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit1_51_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_51 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_51 as text
%        str2double(get(hObject,'String')) returns contents of edit1_51 as a double


% --- Executes during object creation, after setting all properties.
function edit1_51_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_51 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_52_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_52 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_52 as text
%        str2double(get(hObject,'String')) returns contents of edit1_52 as a double


% --- Executes during object creation, after setting all properties.
function edit1_52_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_52 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_53_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_53 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_53 as text
%        str2double(get(hObject,'String')) returns contents of edit1_53 as a double


% --- Executes during object creation, after setting all properties.
function edit1_53_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_53 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_54_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_54 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_54 as text
%        str2double(get(hObject,'String')) returns contents of edit1_54 as a double


% --- Executes during object creation, after setting all properties.
function edit1_54_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_54 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_61_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_61 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_61 as text
%        str2double(get(hObject,'String')) returns contents of edit1_61 as a double


% --- Executes during object creation, after setting all properties.
function edit1_61_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_61 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_62_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_62 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_62 as text
%        str2double(get(hObject,'String')) returns contents of edit1_62 as a double


% --- Executes during object creation, after setting all properties.
function edit1_62_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_62 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_63_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_63 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_63 as text
%        str2double(get(hObject,'String')) returns contents of edit1_63 as a double


% --- Executes during object creation, after setting all properties.
function edit1_63_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_63 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_64_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_64 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_64 as text
%        str2double(get(hObject,'String')) returns contents of edit1_64 as a double


% --- Executes during object creation, after setting all properties.
function edit1_64_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_64 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

%%
function edit1_rank1_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_rank1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_rank1 as text
%        str2double(get(hObject,'String')) returns contents of edit1_rank1 as a double


% --- Executes during object creation, after setting all properties.
function edit1_rank1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_rank1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_rank2_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_rank2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_rank2 as text
%        str2double(get(hObject,'String')) returns contents of edit1_rank2 as a double


% --- Executes during object creation, after setting all properties.
function edit1_rank2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_rank2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_rank3_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_rank3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_rank3 as text
%        str2double(get(hObject,'String')) returns contents of edit1_rank3 as a double


% --- Executes during object creation, after setting all properties.
function edit1_rank3_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_rank3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_rank4_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_rank4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_rank4 as text
%        str2double(get(hObject,'String')) returns contents of edit1_rank4 as a double


% --- Executes during object creation, after setting all properties.
function edit1_rank4_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_rank4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_rank5_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_rank5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_rank5 as text
%        str2double(get(hObject,'String')) returns contents of edit1_rank5 as a double


% --- Executes during object creation, after setting all properties.
function edit1_rank5_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_rank5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


%%


function edit1_cen1_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_cen1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_cen1 as text
%        str2double(get(hObject,'String')) returns contents of edit1_cen1 as a double


% --- Executes during object creation, after setting all properties.
function edit1_cen1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_cen1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_cen2_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_cen2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_cen2 as text
%        str2double(get(hObject,'String')) returns contents of edit1_cen2 as a double


% --- Executes during object creation, after setting all properties.
function edit1_cen2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_cen2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_cen3_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_cen3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_cen3 as text
%        str2double(get(hObject,'String')) returns contents of edit1_cen3 as a double


% --- Executes during object creation, after setting all properties.
function edit1_cen3_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_cen3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_cen4_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_cen4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_cen4 as text
%        str2double(get(hObject,'String')) returns contents of edit1_cen4 as a double


% --- Executes during object creation, after setting all properties.
function edit1_cen4_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_cen4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_cen5_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_cen5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_cen5 as text
%        str2double(get(hObject,'String')) returns contents of edit1_cen5 as a double


% --- Executes during object creation, after setting all properties.
function edit1_cen5_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_cen5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

%%

function edit1_sim11_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim11 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim11 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim11_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit1_sim12_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim12 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim12 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim12_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim13_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim13 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim13 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim13 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim13_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim13 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim14_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim14 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim14 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim14_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim15_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim15 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim15 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim15 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim15_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim15 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim21_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim21 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim21 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim21_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim22_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim22 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim22 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim22 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim22_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim22 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim23_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim23 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim23 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim23 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim23_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim23 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim24_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim24 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim24 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim24 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim24_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim24 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim25_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim25 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim25 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim25 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim25_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim25 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim31_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim31 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim31 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim31_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit1_sim32_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim33 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim33 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim32_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit1_sim33_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim33 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim33 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim33_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit1_sim34_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim34 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim34 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim34_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim35_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim35 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim35 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim35 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim35_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim35 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim41_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim41 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim41 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim41 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim41_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim41 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit1_sim42_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim42 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim42 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim42 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim42_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim42 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit1_sim43_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim43 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim43 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim43_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim44_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim44 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim44 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim44_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim45_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim45 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim45 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim45 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim45_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim45 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit1_sim51_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim51 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim51 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim51 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim51_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim51 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim52_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim52 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim52 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim52 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim52_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim52 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim53_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim53 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim53 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim53 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim53_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim53 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim54_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim54 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim54 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim54 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim54_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim54 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim55_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim55 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim55 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim55 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim55_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim55 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function edit2_11_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_11 as text
%        str2double(get(hObject,'String')) returns contents of edit1_11 as a double


% --- Executes during object creation, after setting all properties.
function edit2_11_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_12_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_12 as text
%        str2double(get(hObject,'String')) returns contents of edit1_12 as a double


% --- Executes during object creation, after setting all properties.
function edit2_12_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_13_Callback(hObject, eventdata, handles)
% hObject    handle to edit3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3 as text
%        str2double(get(hObject,'String')) returns contents of edit3 as a double


% --- Executes during object creation, after setting all properties.
function edit2_13_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_14_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_14 as text
%        str2double(get(hObject,'String')) returns contents of edit1_14 as a double


% --- Executes during object creation, after setting all properties.
function edit2_14_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit2_21_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_21 as text
%        str2double(get(hObject,'String')) returns contents of edit1_21 as a double


% --- Executes during object creation, after setting all properties.
function edit2_21_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit2_22_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_21 as text
%        str2double(get(hObject,'String')) returns contents of edit1_21 as a double


% --- Executes during object creation, after setting all properties.
function edit2_22_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit2_23_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_23 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_23 as text
%        str2double(get(hObject,'String')) returns contents of edit1_23 as a double


% --- Executes during object creation, after setting all properties.
function edit2_23_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_23 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_24_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_24 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_24 as text
%        str2double(get(hObject,'String')) returns contents of edit1_24 as a double


% --- Executes during object creation, after setting all properties.
function edit2_24_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_24 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit2_31_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_31 as text
%        str2double(get(hObject,'String')) returns contents of edit1_31 as a double


% --- Executes during object creation, after setting all properties.
function edit2_31_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function edit2_32_Callback(hObject, eventdata, handles)
% hObject    andle to edit1_34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_34 as text
%        str2double(get(hObject,'String')) returns contents of edit1_34 as a double


% --- Executes during object creation, after setting all properties.
function edit2_32_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function edit2_33_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_33 as text
%        str2double(get(hObject,'String')) returns contents of edit1_33 as a double


% --- Executes during object creation, after setting all properties.
function edit2_33_CreateFcn(hObject, eventdata, handles)
% hObject    andle to edit1_33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_34_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_34 as text
%        str2double(get(hObject,'String')) returns contents of edit1_34 as a double


% --- Executes during object creation, after setting all properties.
function edit2_34_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit2_41_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_41 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_41 as text
%        str2double(get(hObject,'String')) returns contents of edit1_41 as a double


% --- Executes during object creation, after setting all properties.
function edit2_41_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_41 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit2_42_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_44 as text
%        str2double(get(hObject,'String')) returns contents of edit1_44 as a double


% --- Executes during object creation, after setting all properties.
function edit2_42_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit2_43_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_43 as text
%        str2double(get(hObject,'String')) returns contents of edit1_43 as a double


% --- Executes during object creation, after setting all properties.
function edit2_43_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit2_44_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_44 as text
%        str2double(get(hObject,'String')) returns contents of edit1_44 as a double


% --- Executes during object creation, after setting all properties.
function edit2_44_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit2_51_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_51 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_51 as text
%        str2double(get(hObject,'String')) returns contents of edit1_51 as a double


% --- Executes during object creation, after setting all properties.
function edit2_51_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_51 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_52_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_52 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_52 as text
%        str2double(get(hObject,'String')) returns contents of edit1_52 as a double


% --- Executes during object creation, after setting all properties.
function edit2_52_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_52 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_53_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_53 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_53 as text
%        str2double(get(hObject,'String')) returns contents of edit1_53 as a double


% --- Execute during object creation, after setting all properties.
function edit2_53_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_53 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_54_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_54 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_54 as text
%        str2double(get(hObject,'String')) returns contents of edit1_54 as a double


% --- Executes during object creation, after setting all properties.
function edit2_54_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_54 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_61_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_61 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_61 as text
%        str2double(get(hObject,'String')) returns contents of edit1_61 as a double


% --- Execute during object creation, after setting all properties.
function edit2_61_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_61 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_62_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_62 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_62 as text
%        str2double(get(hObject,'String')) returns contents of edit1_62 as a double


% --- Executes during object creation, after setting all properties.
function edit2_62_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_62 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function edit2_63_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_63 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_63 as text
%        str2double(get(hObject,'String')) returns contents of edit1_63 as a double


% --- Executes during object creation, after setting all properties.
function edit2_63_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_63 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_64_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_64 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_64 as text
%        str2double(get(hObject,'String')) returns contents of edit1_64 as a double


% --- Executes during object creation, after setting all properties.
function edit2_64_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_64 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

%%
function edit2_rank1_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_rank1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_rank1 as text
%        str2double(get(hObject,'String')) returns contents of edit1_rank1 as a double


% --- Executes during object creation, after setting all properties.
function edit2_rank1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_rank1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_rank2_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_rank2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_rank2 as text
%        str2double(get(hObject,'String')) returns contents of edit1_rank2 as a double


% --- Executes during object creation, after setting all properties.
function edit2_rank2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_rank2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_rank3_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_rank3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_rank3 as text
%        str2double(get(hObject,'String')) returns contents of edit1_rank3 as a double


% --- Executes during object creation, after setting all properties.
function edit2_rank3_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_rank3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_rank4_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_rank4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_rank4 as text
%        str2double(get(hObject,'String')) returns contents of edit1_rank4 as a double


% --- Executes during object creation, after setting all properties.
function edit2_rank4_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_rank4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_rank5_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_rank5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_rank5 as text
%        str2double(get(hObject,'String')) returns contents of edit1_rank5 as a double


% --- Executes during object creation, after setting all properties.
function edit2_rank5_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_rank5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


%%
function edit2_cen1_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_cen1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_cen1 as text
%        str2double(get(hObject,'String')) returns contents of edit1_cen1 as a double


% --- Executes during object creation, after setting all properties.
function edit2_cen1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_cen1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_cen2_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_cen2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_cen2 as text
%        str2double(get(hObject,'String')) returns contents of edit1_cen2 as a double


% --- Executes during object creation, after setting all properties.
function edit2_cen2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_cen2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_cen3_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_cen3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_cen3 as text
%        str2double(get(hObject,'String')) returns contents of edit1_cen3 as a double


% --- Executes during object creation, after setting all properties.
function edit2_cen3_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_cen3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_cen4_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_cen4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_cen4 as text
%        str2double(get(hObject,'String')) returns contents of edit1_cen4 as a double


% --- Executes during object creation, after setting all properties.
function edit2_cen4_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_cen4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_cen5_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_cen5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_cen5 as text
%        str2double(get(hObject,'String')) returns contents of edit1_cen5 as a double


% --- Executes during object creation, after setting all properties.
function edit2_cen5_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_cen5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

%%

function edit2_sim11_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim11 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim11 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim11_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit2_sim12_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim12 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim12 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim12_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_sim13_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim13 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim13 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim13 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim13_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim13 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_sim14_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim14 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim14 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim14_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_sim15_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim15 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim15 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim15 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim15_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim15 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_sim21_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim21 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim21 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim21_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_sim22_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim22 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim22 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim22 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim22_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim22 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_sim23_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim23 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim23 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim23 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim23_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim23 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_sim24_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim24 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim24 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim24 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim24_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim24 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_sim25_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim25 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim25 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim25 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim25_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim25 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_sim31_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim31 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim31 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim31_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit2_sim32_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim33 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim33 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim32_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit2_sim33_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim33 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim33 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim33_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit2_sim34_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim34 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim34 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim34_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_sim35_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim35 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim35 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim35 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim35_CreateFcn(hObject, eventdata, handles)
% hObject    andle to edit1_sim35 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_sim41_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim41 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim41 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim41 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim41_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim41 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit2_sim42_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim42 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim42 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim42 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim42_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim42 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit2_sim43_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim43 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim43 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim43_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_sim44_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim44 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim44 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim44_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_sim45_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim45 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim45 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim45 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim45_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim45 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit2_sim51_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim51 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim51 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim51 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim51_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim51 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_sim52_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim52 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim52 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim52 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim52_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim52 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_sim53_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim53 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim53 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim53 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim53_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim53 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_sim54_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim54 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim54 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim54 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim54_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim54 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_sim55_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim55 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim55 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim55 as a double


% --- Executes during object creation, after setting all properties.
function edit2_sim55_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim55 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



function edit3_11_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_11 as text
%        str2double(get(hObject,'String')) returns contents of edit3_11 as a double


% --- Executes during object creation, after setting all properties.
function edit3_11_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_12_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_12 as text
%        str2double(get(hObject,'String')) returns contents of edit3_12 as a double


% --- Executes during object creation, after setting all properties.
function edit3_12_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_13_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_13 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_13 as text
%        str2double(get(hObject,'String')) returns contents of edit3_13 as a double


% --- Executes during object creation, after setting all properties.
function edit3_13_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_13 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_14_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_14 as text
%        str2double(get(hObject,'String')) returns contents of edit3_14 as a double


% --- Executes during object creation, after setting all properties.
function edit3_14_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_21_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_21 as text
%        str2double(get(hObject,'String')) returns contents of edit3_21 as a double


% --- Executes during object creation, after setting all properties.
function edit3_21_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_22_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_22 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_22 as text
%        str2double(get(hObject,'String')) returns contents of edit3_22 as a double


% --- Executes during object creation, after setting all properties.
function edit3_22_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_22 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_23_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_23 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_23 as text
%        str2double(get(hObject,'String')) returns contents of edit3_23 as a double


% --- Executes during object creation, after setting all properties.
function edit3_23_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_23 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_24_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_24 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_24 as text
%        str2double(get(hObject,'String')) returns contents of edit3_24 as a double


% --- Executes during object creation, after setting all properties.
function edit3_24_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_24 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_31_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_31 as text
%        str2double(get(hObject,'String')) returns contents of edit3_31 as a double


% --- Executes during object creation, after setting all properties.
function edit3_31_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_32_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_32 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_32 as text
%        str2double(get(hObject,'String')) returns contents of edit3_32 as a double


% --- Executes during object creation, after setting all properties.
function edit3_32_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_32 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit3_33_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_33 as text
%        str2double(get(hObject,'String')) returns contents of edit3_33 as a double


% --- Executes during object creation, after setting all properties.
function edit3_33_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function edit3_34_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_34 as text
%        str2double(get(hObject,'String')) returns contents of edit3_34 as a double


% --- Executes during object creation, after setting all properties.
function edit3_34_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

%%

function edit3_41_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_41 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_41 as text
%        str2double(get(hObject,'String')) returns contents of edit3_41 as a double


% --- Executes during object creation, after setting all properties.
function edit3_41_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_41 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit3_42_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_42 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_42 as text
%        str2double(get(hObject,'String')) returns contents of edit3_42 as a double


% --- Executes during object creation, after setting all properties.
function edit3_42_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_42 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit3_43_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_43 as text
%        str2double(get(hObject,'String')) returns contents of edit3_43 as a double


% --- Executes during object creation, after setting all properties.
function edit3_43_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit3_44_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_44 as text
%        str2double(get(hObject,'String')) returns contents of edit3_44 as a double


% --- Executes during object creation, after setting all properties.
function edit3_44_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_51_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_51 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_51 as text
%        str2double(get(hObject,'String')) returns contents of edit3_51 as a double


% --- Executes during object creation, after setting all properties.
function edit3_51_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_51 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit3_52_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_52 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_52 as text
%        str2double(get(hObject,'String')) returns contents of edit3_52 as a double


% --- Executes during object creation, after setting all properties.
function edit3_52_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_52 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function edit3_53_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_53 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_53 as text
%        str2double(get(hObject,'String')) returns contents of edit3_53 as a double


% --- Executes during object creation, after setting all properties.
function edit3_53_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_53 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit3_54_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_54 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_54 as text
%        str2double(get(hObject,'String')) returns contents of edit3_54 as a double


% --- Executes during object creation, after setting all properties.
function edit3_54_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_54 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end




function edit3_61_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_61 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_61 as text
%        str2double(get(hObject,'String')) returns contents of edit3_61 as a double


% --- Executes during object creation, after setting all properties.
function edit3_61_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_61 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit3_62_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_62 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_62 as text
%        str2double(get(hObject,'String')) returns contents of edit3_62 as a double


% --- Executes during object creation, after setting all properties.
function edit3_62_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_62 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function edit3_63_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_63 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_63 as text
%        str2double(get(hObject,'String')) returns contents of edit3_63 as a double


% --- Executes during object creation, after setting all properties.
function edit3_63_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_63 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit3_64_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_64 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_64 as text
%        str2double(get(hObject,'String')) returns contents of edit3_64 as a double


% --- Executes during object creation, after setting all properties.
function edit3_64_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_64 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

%%

function edit3_cen1_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_cen1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_cen1 as text
%        str2double(get(hObject,'String')) returns contents of edit3_cen1 as a double


% --- Executes during object creation, after setting all properties.
function edit3_cen1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_cen1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_cen2_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_cen2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_cen2 as text
%        str2double(get(hObject,'String')) returns contents of edit3_cen2 as a double


% --- Executes during object creation, after setting all properties.
function edit3_cen2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_cen2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function edit3_cen4_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_cen4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_cen4 as text
%        str2double(get(hObject,'String')) returns contents of edit3_cen4 as a double


% --- Executes during object creation, after setting all properties.
function edit3_cen4_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_cen4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_cen5_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_cen5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_cen5 as text
%        str2double(get(hObject,'String')) returns contents of edit3_cen5 as a double


% --- Executes during object creation, after setting all properties.
function edit3_cen5_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_cen5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_cen3_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_cen3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_cen3 as text
%        str2double(get(hObject,'String')) returns contents of edit3_cen3 as a double


% --- Executes during object creation, after setting all properties.
function edit3_cen3_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_cen3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


%%

function edit3_rank3_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_rank3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_rank3 as text
%        str2double(get(hObject,'String')) returns contents of edit3_rank3 as a double


% --- Executes during object creation, after setting all properties.
function edit3_rank3_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_rank3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_rank5_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_rank5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_rank5 as text
%        str2double(get(hObject,'String')) returns contents of edit3_rank5 as a double


% --- Executes during object creation, after setting all properties.
function edit3_rank5_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_rank5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_rank4_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_rank4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_rank4 as text
%        str2double(get(hObject,'String')) returns contents of edit3_rank4 as a double


% --- Executes during object creation, after setting all properties.
function edit3_rank4_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_rank4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end





function edit3_rank1_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_rank1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_rank1 as text
%        str2double(get(hObject,'String')) returns contents of edit3_rank1 as a double


% --- Executes during object creation, after setting all properties.
function edit3_rank1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_rank1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_rank2_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_rank2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_rank2 as text
%        str2double(get(hObject,'String')) returns contents of edit3_rank2 as a double


% --- Executes during object creation, after setting all properties.
function edit3_rank2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_rank2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
%%


function edit3_sim11_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim11 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim11 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim11_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim12_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim12 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim12 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim12_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim13_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim13 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim13 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim13 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim13_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim13 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim14_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim14 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim14 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim14_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim15_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim15 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim15 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim15 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim15_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim15 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim21_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim21 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim21 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim21_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim22_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim22 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim22 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim22 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim22_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim22 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim23_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim23 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim23 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim23 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim23_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim23 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim24_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim24 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim24 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim24 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim24_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim24 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim25_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim25 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim25 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim25 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim25_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim25 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim31_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim31 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim31 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim31_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim32_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim32 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim32 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim32 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim32_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim32 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim33_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim33 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim33 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim33_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim34_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim34 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim34 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim34_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim35_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim35 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim35 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim35 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim35_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim35 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim41_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim41 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim41 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim41 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim41_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim41 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim51_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim51 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim51 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim51 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim51_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim51 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim42_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim42 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim42 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim42 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim42_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim42 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim43_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim43 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim43 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim43_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim44_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim44 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim44 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim44_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim45_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim45 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim45 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim45 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim45_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim45 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim52_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim52 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim52 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim52 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim52_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim52 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim53_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim53 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim53 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim53 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim53_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim53 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim54_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim54 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim54 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim54 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim54_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim54 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_sim55_Callback(hObject, eventdata, handles)
% hObject    handle to edit3_sim55 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3_sim55 as text
%        str2double(get(hObject,'String')) returns contents of edit3_sim55 as a double


% --- Executes during object creation, after setting all properties.
function edit3_sim55_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3_sim55 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

%%%



global XS1 WS1 XS2 XS3 WS2 WS3
%% 
% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

global XS1 WS1 Special XS2 XS3 WS2 WS3
global ppmenu11 ppmenu12 ppmenu13 ppmenu14 ppmenu21 ppmenu22 ppmenu23 ppmenu24
global ppmenu31 ppmenu32 ppmenu33 ppmenu34 ppmenu41 ppmenu42 ppmenu43 ppmenu44
global ppmenu51 ppmenu52 ppmenu53 ppmenu54 ppmenu61 ppmenu62 ppmenu63 ppmenu64 
global popupmenu61 counter

%% 1st Set of Data
global XS1 WS1 XXS1 XXL1 XXR1 XXSM1 XXSL1 XXSR1
global ling1_11 ling1_12 ling1_13 ling1_14
global ling1_21 ling1_22 ling1_23 ling1_24
global ling1_31 ling1_32 ling1_33 ling1_34
global ling1_41 ling1_42 ling1_43 ling1_44
global ling1_51 ling1_52 ling1_53 ling1_54
global ling1_61 ling1_62 ling1_63 ling1_64
global rank1_1 rank1_2 rank1_3 rank1_4 rank1_5
global cen1_1 cen1_2 cen1_3 cen1_4 cen1_5
global sim1_11 sim1_12 sim1_13 sim1_14 sim1_15
global sim1_21 sim1_22 sim1_23 sim1_24 sim1_25
global sim1_31 sim1_32 sim1_33 sim1_34 sim1_35
global sim1_41 sim1_42 sim1_43 sim1_44 sim1_45
global sim1_51 sim1_52 sim1_53 sim1_54 sim1_55

%% 2nd Set of Data
global XS2 WS2 XXS2 XXL2 XXR2 XXSM2 XXSL2 XXSR2
global ling2_11 ling2_12 ling2_13 ling2_14
global ling2_21 ling2_22 ling2_23 ling2_24
global ling2_31 ling2_32 ling2_33 ling2_34
global ling2_41 ling2_42 ling2_43 ling2_44
global ling2_51 ling2_52 ling2_53 ling2_54
global ling2_61 ling2_62 ling2_63 ling2_64
global rank2_1 rank2_2 rank2_3 rank2_4 rank2_5
global cen2_1 cen2_2 cen2_3 cen2_4 cen2_5
global sim2_11 sim2_12 sim2_13 sim2_14 sim2_15
global sim2_21 sim2_22 sim2_23 sim2_24 sim2_25
global sim2_31 sim2_32 sim2_33 sim2_34 sim2_35
global sim2_41 sim2_42 sim2_43 sim2_44 sim2_45
global sim2_51 sim2_52 sim2_53 sim2_54 sim2_55

%% 3rd Set of Data
global XS3 WS3 XXS3 XXL3 XXR3 XXSM3 XXSL3 XXSR3
global ling3_11 ling3_12 ling3_13 ling3_14
global ling3_21 ling3_22 ling3_23 ling3_24
global ling3_31 ling3_32 ling3_33 ling3_34
global ling3_41 ling3_42 ling3_43 ling3_44
global ling3_51 ling3_52 ling3_53 ling3_54
global ling3_61 ling3_62 ling3_63 ling3_64
global rank3_1 rank3_2 rank3_3 rank3_4 rank3_5
global cen3_1 cen3_2 cen3_3 cen3_4 cen3_5
global sim3_11 sim3_12 sim3_13 sim3_14 sim3_15
global sim3_21 sim3_22 sim3_23 sim3_24 sim3_25
global sim3_31 sim3_32 sim3_33 sim3_34 sim3_35
global sim3_41 sim3_42 sim3_43 sim3_44 sim3_45
global sim3_51 sim3_52 sim3_53 sim3_54 sim3_55 WhichInv templet



WS1;
WS2;
WS3;
counter=1;
SaveParameters11;


Special=1;

XS1_1=[]; XS1_2=[]; XS1_3=[]; XS1_4=[]; XS1_5=[];
XS1_1=XS1(1,:);
XS1_2=XS1(2,:);
XS1_3=XS1(3,:);
XS1_4=XS1(4,:);
XS1_5=XS1(5,:);

ppmenu11=XS1_1(1); ppmenu12=XS1_1(2); ppmenu13=XS1_1(3); ppmenu14=XS1_1(4);
ppmenu21=XS1_2(1); ppmenu22=XS1_2(2); ppmenu23=XS1_2(3); ppmenu24=XS1_2(4);
ppmenu31=XS1_3(1); ppmenu32=XS1_3(2); ppmenu33=XS1_3(3); ppmenu34=XS1_3(4);
ppmenu41=XS1_4(1); ppmenu42=XS1_4(2); ppmenu43=XS1_4(3); ppmenu44=XS1_4(4);
ppmenu51=XS1_5(1); ppmenu52=XS1_5(2); ppmenu53=XS1_5(3); ppmenu54=XS1_5(4);
ppmenu61=WS1(1);
ppmenu62=WS1(2);
ppmenu63=WS1(3);
ppmenu64=WS1(4);
Special=1;

if templet==1
    WhichInv=1;
end

templet=0;
close all;
IJA;



% --- Executes on button press in pushbutton2.
function pushbutton2_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global XS2 WS2 counter WhichInv


global ppmenu11 ppmenu12 ppmenu13 ppmenu14 ppmenu21 ppmenu22 ppmenu23 ppmenu24
global ppmenu31 ppmenu32 ppmenu33 ppmenu34 ppmenu41 ppmenu42 ppmenu43 ppmenu44
global ppmenu51 ppmenu52 ppmenu53 ppmenu54 ppmenu61 ppmenu62 ppmenu63 ppmenu64 
counter=1;
%% 1st Set of Data
global XS1 WS1 XXS1 XXL1 XXR1 XXSM1 XXSL1 XXSR1
global ling1_11 ling1_12 ling1_13 ling1_14
global ling1_21 ling1_22 ling1_23 ling1_24
global ling1_31 ling1_32 ling1_33 ling1_34
global ling1_41 ling1_42 ling1_43 ling1_44
global ling1_51 ling1_52 ling1_53 ling1_54
global ling1_61 ling1_62 ling1_63 ling1_64
global rank1_1 rank1_2 rank1_3 rank1_4 rank1_5
global cen1_1 cen1_2 cen1_3 cen1_4 cen1_5
global sim1_11 sim1_12 sim1_13 sim1_14 sim1_15
global sim1_21 sim1_22 sim1_23 sim1_24 sim1_25
global sim1_31 sim1_32 sim1_33 sim1_34 sim1_35
global sim1_41 sim1_42 sim1_43 sim1_44 sim1_45
global sim1_51 sim1_52 sim1_53 sim1_54 sim1_55

%% 2nd Set of Data
global XS2 WS2 XXS2 XXL2 XXR2 XXSM2 XXSL2 XXSR2
global ling2_11 ling2_12 ling2_13 ling2_14
global ling2_21 ling2_22 ling2_23 ling2_24
global ling2_31 ling2_32 ling2_33 ling2_34
global ling2_41 ling2_42 ling2_43 ling2_44
global ling2_51 ling2_52 ling2_53 ling2_54
global ling2_61 ling2_62 ling2_63 ling2_64
global rank2_1 rank2_2 rank2_3 rank2_4 rank2_5
global cen2_1 cen2_2 cen2_3 cen2_4 cen2_5
global sim2_11 sim2_12 sim2_13 sim2_14 sim2_15
global sim2_21 sim2_22 sim2_23 sim2_24 sim2_25
global sim2_31 sim2_32 sim2_33 sim2_34 sim2_35
global sim2_41 sim2_42 sim2_43 sim2_44 sim2_45
global sim2_51 sim2_52 sim2_53 sim2_54 sim2_55

%% 3rd Set of Data
global XS3 WS3 XXS3 XXL3 XXR3 XXSM3 XXSL3 XXSR3 templet
global ling3_11 ling3_12 ling3_13 ling3_14
global ling3_21 ling3_22 ling3_23 ling3_24
global ling3_31 ling3_32 ling3_33 ling3_34
global ling3_41 ling3_42 ling3_43 ling3_44
global ling3_51 ling3_52 ling3_53 ling3_54
global ling3_61 ling3_62 ling3_63 ling3_64
global rank3_1 rank3_2 rank3_3 rank3_4 rank3_5
global cen3_1 cen3_2 cen3_3 cen3_4 cen3_5
global sim3_11 sim3_12 sim3_13 sim3_14 sim3_15
global sim3_21 sim3_22 sim3_23 sim3_24 sim3_25
global sim3_31 sim3_32 sim3_33 sim3_34 sim3_35
global sim3_41 sim3_42 sim3_43 sim3_44 sim3_45
global sim3_51 sim3_52 sim3_53 sim3_54 sim3_55 templet
% msgbox('Please wait while processing....');
Special=0;
SaveParameters22;

%% Clear 1st Set of Data
XS1=[]; WS1=[]; XXS1=[]; XXL1=[]; XXR1=[]; XXSM1=[]; XXSL1=[]; XXSR1=[];
ling1_11=[]; ling1_12=[]; ling1_13=[]; ling1_14=[];
ling1_21=[]; ling1_22=[]; ling1_23=[]; ling1_24=[];
ling1_31=[]; ling1_32=[]; ling1_33=[]; ling1_34=[];
ling1_41=[]; ling1_42=[]; ling1_43=[]; ling1_44=[];
ling1_51=[]; ling1_52=[]; ling1_53=[]; ling1_54=[];
ling1_61=[]; ling1_62=[]; ling1_63=[]; ling1_64=[];
rank1_1=[]; rank1_2=[]; rank1_3=[]; rank1_4=[]; rank1_5=[];
cen1_1=[]; cen1_2=[]; cen1_3=[]; cen1_4=[]; cen1_5=[];
sim1_11=[]; sim1_12=[]; sim1_13=[]; sim1_14=[]; sim1_15=[];
sim1_21=[]; sim1_22=[]; sim1_23=[]; sim1_24=[]; sim1_25=[];
sim1_31=[]; sim1_32=[]; sim1_33=[]; sim1_34=[]; sim1_35=[];
sim1_41=[]; sim1_42=[]; sim1_43=[]; sim1_44=[]; sim1_45=[];
sim1_51=[]; sim1_52=[]; sim1_53=[]; sim1_54=[]; sim1_55=[];

%% Put 2nd Set -> 1st
%%% 2nd Set of Data
XS1=XS2; WS1=WS2; XXS1=XXS2; XXL1=XXL2; XXR1=XXR2; XXSM1=XXSM2; XXSL1=XXSL2; XXSR1=XXSR2;
ling1_11=ling2_11; ling1_12=ling2_12; ling1_13=ling2_13; ling1_14=ling2_14;
ling1_21=ling2_21; ling1_22=ling2_22; ling1_23=ling2_23; ling1_24=ling2_24;
ling1_31=ling2_31; ling1_32=ling2_32; ling1_33=ling2_33; ling1_34=ling2_34;
ling1_41=ling2_41; ling1_42=ling2_42; ling1_43=ling2_43; ling1_44=ling2_44;
ling1_51=ling2_51; ling1_52=ling2_52; ling1_53=ling2_53; ling1_54=ling2_54;
ling1_61=ling2_61; ling1_62=ling2_62; ling1_63=ling2_63; ling1_64=ling2_64;
rank1_1=rank2_1; rank1_2=rank2_2; rank1_3=rank2_3; rank1_4=rank2_4; rank1_5=rank2_5;
cen1_1=cen2_1; cen1_2=cen2_2; cen1_3=cen2_3; cen1_4=cen2_4; cen1_5=cen2_5;
sim1_11=sim2_11; sim1_12=sim2_12; sim1_13=sim2_13; sim1_14=sim2_14; sim1_15=sim2_15;
sim1_21=sim2_21; sim1_22=sim2_22; sim1_23=sim2_23; sim1_24=sim2_24; sim1_25=sim2_25;
sim1_31=sim2_31; sim1_32=sim2_32; sim1_33=sim2_33; sim1_34=sim2_34; sim1_35=sim2_35;
sim1_41=sim2_41; sim1_42=sim2_42; sim1_43=sim2_43; sim1_44=sim2_44; sim1_45=sim2_45;
sim1_51=sim2_51; sim1_52=sim2_52; sim1_53=sim2_53; sim1_54=sim2_54; sim1_55=sim2_55;

XS1_1=[]; XS1_2=[]; XS1_3=[]; XS1_4=[]; XS1_5=[];
XS1_1=XS2(1,:);
XS1_2=XS2(2,:);
XS1_3=XS2(3,:);
XS1_4=XS2(4,:);
XS1_5=XS2(5,:);

ppmenu11=XS1_1(1); ppmenu12=XS1_1(2); ppmenu13=XS1_1(3); ppmenu14=XS1_1(4);
ppmenu21=XS1_2(1); ppmenu22=XS1_2(2); ppmenu23=XS1_2(3); ppmenu24=XS1_2(4);
ppmenu31=XS1_3(1); ppmenu32=XS1_3(2); ppmenu33=XS1_3(3); ppmenu34=XS1_3(4);
ppmenu41=XS1_4(1); ppmenu42=XS1_4(2); ppmenu43=XS1_4(3); ppmenu44=XS1_4(4);
ppmenu51=XS1_5(1); ppmenu52=XS1_5(2); ppmenu53=XS1_5(3); ppmenu54=XS1_5(4);
ppmenu61=WS2(1);
ppmenu62=WS2(2);
ppmenu63=WS2(3);
ppmenu64=WS2(4);

counter=1;

if templet==1
    WhichInv=2;
end


templet=0;
close all;
IJA;

%%
% --- Executes on button press in pushbutton3.
function pushbutton3_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global ppmenu11 ppmenu12 ppmenu13 ppmenu14 ppmenu21 ppmenu22 ppmenu23 ppmenu24
    global ppmenu31 ppmenu32 ppmenu33 ppmenu34 ppmenu41 ppmenu42 ppmenu43 ppmenu44
    global ppmenu51 ppmenu52 ppmenu53 ppmenu54 ppmenu61 ppmenu62 ppmenu63 ppmenu64 templet
%% Previous Parameters (-1th Set)
global XSp WSp XXSp XXLp XXRp XXSMp XXSLp XXSRp WhichInv
global lingp_11 lingp_12 lingp_13 lingp_14
global lingp_21 lingp_22 lingp_23 lingp_24
global lingp_31 lingp_32 lingp_33 lingp_34
global lingp_41 lingp_42 lingp_43 lingp_44
global lingp_51 lingp_52 lingp_53 lingp_54
global lingp_61 lingp_62 lingp_63 lingp_64
global rankp_1 rankp_2 rankp_3 rankp_4 rankp_5
global cenp_1 cenp_2 cenp_3 cenp_4 cenp_5
global simp_11 simp_12 simp_13 simp_14 simp_15
global simp_21 simp_22 simp_23 simp_24 simp_25
global simp_31 simp_32 simp_33 simp_34 simp_35
global simp_41 simp_42 simp_43 simp_44 simp_45
global simp_51 simp_52 simp_53 simp_54 simp_55

    %% 1st Set of Data
global XS1 WS1 XXS1 XXL1 XXR1 XXSM1 XXSL1 XXSR1
global ling1_11 ling1_12 ling1_13 ling1_14
global ling1_21 ling1_22 ling1_23 ling1_24
global ling1_31 ling1_32 ling1_33 ling1_34
global ling1_41 ling1_42 ling1_43 ling1_44
global ling1_51 ling1_52 ling1_53 ling1_54
global ling1_61 ling1_62 ling1_63 ling1_64
global rank1_1 rank1_2 rank1_3 rank1_4 rank1_5
global cen1_1 cen1_2 cen1_3 cen1_4 cen1_5
global sim1_11 sim1_12 sim1_13 sim1_14 sim1_15
global sim1_21 sim1_22 sim1_23 sim1_24 sim1_25
global sim1_31 sim1_32 sim1_33 sim1_34 sim1_35
global sim1_41 sim1_42 sim1_43 sim1_44 sim1_45
global sim1_51 sim1_52 sim1_53 sim1_54 sim1_55

%% 2nd Set of Data
global XS2 WS2 XXS2 XXL2 XXR2 XXSM2 XXSL2 XXSR2
global ling2_11 ling2_12 ling2_13 ling2_14
global ling2_21 ling2_22 ling2_23 ling2_24
global ling2_31 ling2_32 ling2_33 ling2_34
global ling2_41 ling2_42 ling2_43 ling2_44
global ling2_51 ling2_52 ling2_53 ling2_54
global ling2_61 ling2_62 ling2_63 ling2_64
global rank2_1 rank2_2 rank2_3 rank2_4 rank2_5
global cen2_1 cen2_2 cen2_3 cen2_4 cen2_5
global sim2_11 sim2_12 sim2_13 sim2_14 sim2_15
global sim2_21 sim2_22 sim2_23 sim2_24 sim2_25
global sim2_31 sim2_32 sim2_33 sim2_34 sim2_35
global sim2_41 sim2_42 sim2_43 sim2_44 sim2_45
global sim2_51 sim2_52 sim2_53 sim2_54 sim2_55

%% 3rd Set of Data
global XS3 WS3 XXS3 XXL3 XXR3 XXSM3 XXSL3 XXSR3
global ling3_11 ling3_12 ling3_13 ling3_14
global ling3_21 ling3_22 ling3_23 ling3_24
global ling3_31 ling3_32 ling3_33 ling3_34
global ling3_41 ling3_42 ling3_43 ling3_44
global ling3_51 ling3_52 ling3_53 ling3_54
global ling3_61 ling3_62 ling3_63 ling3_64
global rank3_1 rank3_2 rank3_3 rank3_4 rank3_5
global cen3_1 cen3_2 cen3_3 cen3_4 cen3_5
global sim3_11 sim3_12 sim3_13 sim3_14 sim3_15
global sim3_21 sim3_22 sim3_23 sim3_24 sim3_25
global sim3_31 sim3_32 sim3_33 sim3_34 sim3_35
global sim3_41 sim3_42 sim3_43 sim3_44 sim3_45
global sim3_51 sim3_52 sim3_53 sim3_54 sim3_55


global XS2 WS2 counter
% clear counter
% counter=1;
global ppmenu11 ppmenu12 ppmenu13 ppmenu14 ppmenu21 ppmenu22 ppmenu23 ppmenu24
global ppmenu31 ppmenu32 ppmenu33 ppmenu34 ppmenu41 ppmenu42 ppmenu43 ppmenu44
global ppmenu51 ppmenu52 ppmenu53 ppmenu54 ppmenu61 ppmenu62 ppmenu63 ppmenu64 

%% 1st Set of Data
global XS1 WS1 XXS1 XXL1 XXR1 XXSM1 XXSL1 XXSR1
global ling1_11 ling1_12 ling1_13 ling1_14
global ling1_21 ling1_22 ling1_23 ling1_24
global ling1_31 ling1_32 ling1_33 ling1_34
global ling1_41 ling1_42 ling1_43 ling1_44
global ling1_51 ling1_52 ling1_53 ling1_54
global ling1_61 ling1_62 ling1_63 ling1_64
global rank1_1 rank1_2 rank1_3 rank1_4 rank1_5
global cen1_1 cen1_2 cen1_3 cen1_4 cen1_5
global sim1_11 sim1_12 sim1_13 sim1_14 sim1_15
global sim1_21 sim1_22 sim1_23 sim1_24 sim1_25
global sim1_31 sim1_32 sim1_33 sim1_34 sim1_35
global sim1_41 sim1_42 sim1_43 sim1_44 sim1_45
global sim1_51 sim1_52 sim1_53 sim1_54 sim1_55

%% 2nd Set of Data
global XS2 WS2 XXS2 XXL2 XXR2 XXSM2 XXSL2 XXSR2
global ling2_11 ling2_12 ling2_13 ling2_14
global ling2_21 ling2_22 ling2_23 ling2_24
global ling2_31 ling2_32 ling2_33 ling2_34
global ling2_41 ling2_42 ling2_43 ling2_44
global ling2_51 ling2_52 ling2_53 ling2_54
global ling2_61 ling2_62 ling2_63 ling2_64
global rank2_1 rank2_2 rank2_3 rank2_4 rank2_5
global cen2_1 cen2_2 cen2_3 cen2_4 cen2_5
global sim2_11 sim2_12 sim2_13 sim2_14 sim2_15
global sim2_21 sim2_22 sim2_23 sim2_24 sim2_25
global sim2_31 sim2_32 sim2_33 sim2_34 sim2_35
global sim2_41 sim2_42 sim2_43 sim2_44 sim2_45
global sim2_51 sim2_52 sim2_53 sim2_54 sim2_55

%% 3rd Set of Data
global XS3 WS3 XXS3 XXL3 XXR3 XXSM3 XXSL3 XXSR3
global ling3_11 ling3_12 ling3_13 ling3_14
global ling3_21 ling3_22 ling3_23 ling3_24
global ling3_31 ling3_32 ling3_33 ling3_34
global ling3_41 ling3_42 ling3_43 ling3_44
global ling3_51 ling3_52 ling3_53 ling3_54
global ling3_61 ling3_62 ling3_63 ling3_64
global rank3_1 rank3_2 rank3_3 rank3_4 rank3_5
global cen3_1 cen3_2 cen3_3 cen3_4 cen3_5
global sim3_11 sim3_12 sim3_13 sim3_14 sim3_15
global sim3_21 sim3_22 sim3_23 sim3_24 sim3_25
global sim3_31 sim3_32 sim3_33 sim3_34 sim3_35
global sim3_41 sim3_42 sim3_43 sim3_44 sim3_45
global sim3_51 sim3_52 sim3_53 sim3_54 sim3_55
global templet counter
% msgbox('Please wait while processing....');
templet;
if templet==1
    WhichInv=3;
end

if templet==1;
    counter=1;    
Special=0;
SaveParameters33;

%% Clear 1st Set of Data
XS1=[]; WS1=[]; XXS1=[]; XXL1=[]; XXR1=[]; XXSM1=[]; XXSL1=[]; XXSR1=[];
ling1_11=[]; ling1_12=[]; ling1_13=[]; ling1_14=[];
ling1_21=[]; ling1_22=[]; ling1_23=[]; ling1_24=[];
ling1_31=[]; ling1_32=[]; ling1_33=[]; ling1_34=[];
ling1_41=[]; ling1_42=[]; ling1_43=[]; ling1_44=[];
ling1_51=[]; ling1_52=[]; ling1_53=[]; ling1_54=[];
ling1_61=[]; ling1_62=[]; ling1_63=[]; ling1_64=[];
rank1_1=[]; rank1_2=[]; rank1_3=[]; rank1_4=[]; rank1_5=[];
cen1_1=[]; cen1_2=[]; cen1_3=[]; cen1_4=[]; cen1_5=[];
sim1_11=[]; sim1_12=[]; sim1_13=[]; sim1_14=[]; sim1_15=[];
sim1_21=[]; sim1_22=[]; sim1_23=[]; sim1_24=[]; sim1_25=[];
sim1_31=[]; sim1_32=[]; sim1_33=[]; sim1_34=[]; sim1_35=[];
sim1_41=[]; sim1_42=[]; sim1_43=[]; sim1_44=[]; sim1_45=[];
sim1_51=[]; sim1_52=[]; sim1_53=[]; sim1_54=[]; sim1_55=[];

%% Put 3rd Set -> 1st
%%% 3rd Set of Data
XS1=XS3; WS1=WS3; XXS1=XXS3; XXL1=XXL3; XXR1=XXR3; XXSM1=XXSM3; XXSL1=XXSL3; XXSR1=XXSR3;
ling1_11=ling3_11; ling1_12=ling3_12; ling1_13=ling3_13; ling1_14=ling3_14;
ling1_21=ling3_21; ling1_22=ling3_22; ling1_23=ling3_23; ling1_24=ling3_24;
ling1_31=ling3_31; ling1_32=ling3_32; ling1_33=ling3_33; ling1_34=ling3_34;
ling1_41=ling3_41; ling1_42=ling3_42; ling1_43=ling3_43; ling1_44=ling3_44;
ling1_51=ling3_51; ling1_52=ling3_52; ling1_53=ling3_53; ling1_54=ling3_54;
ling1_61=ling3_61; ling1_62=ling3_62; ling1_63=ling3_63; ling1_64=ling3_64;
rank1_1=rank3_1; rank1_2=rank3_2; rank1_3=rank3_3; rank1_4=rank3_4; rank1_5=rank3_5;
cen1_1=cen3_1; cen1_2=cen3_2; cen1_3=cen3_3; cen1_4=cen3_4; cen1_5=cen3_5;
sim1_11=sim3_11; sim1_12=sim3_12; sim1_13=sim3_13; sim1_14=sim3_14; sim1_15=sim3_15;
sim1_21=sim3_21; sim1_22=sim3_22; sim1_23=sim3_23; sim1_24=sim3_24; sim1_25=sim3_25;
sim1_31=sim3_31; sim1_32=sim3_32; sim1_33=sim3_33; sim1_34=sim3_34; sim1_35=sim3_35;
sim1_41=sim3_41; sim1_42=sim3_42; sim1_43=sim3_43; sim1_44=sim3_44; sim1_45=sim3_45;
sim1_51=sim3_51; sim1_52=sim3_52; sim1_53=sim3_53; sim1_54=sim3_54; sim1_55=sim3_55;


XS1_1=[]; XS1_2=[]; XS1_3=[]; XS1_4=[]; XS1_5=[];
XS1_1=XS3(1,:);
XS1_2=XS3(2,:);
XS1_3=XS3(3,:);
XS1_4=XS3(4,:);
XS1_5=XS3(5,:);

ppmenu11=XS1_1(1); ppmenu12=XS1_1(2); ppmenu13=XS1_1(3); ppmenu14=XS1_1(4);
ppmenu21=XS1_2(1); ppmenu22=XS1_2(2); ppmenu23=XS1_2(3); ppmenu24=XS1_2(4);
ppmenu31=XS1_3(1); ppmenu32=XS1_3(2); ppmenu33=XS1_3(3); ppmenu34=XS1_3(4);
ppmenu41=XS1_4(1); ppmenu42=XS1_4(2); ppmenu43=XS1_4(3); ppmenu44=XS1_4(4);
ppmenu51=XS1_5(1); ppmenu52=XS1_5(2); ppmenu53=XS1_5(3); ppmenu54=XS1_5(4);
ppmenu61=WS3(1);
ppmenu62=WS3(2);
ppmenu63=WS3(3);
ppmenu64=WS3(4);

counter=1;
templet=0;
templet;

close all;
IJA;


else

counter;

templet=0;
Special=0;

SaveParameters11; %% Save three sets of current parameters
SaveParameters22;
SaveParameters33;

ClearTheFirstSets;

XS3_1=[]; XS3_2=[]; XS3_3=[]; XS3_4=[]; XS3_5=[];
XS3_1=XS3(1,:);
XS3_2=XS3(2,:);
XS3_3=XS3(3,:);
XS3_4=XS3(4,:);
XS3_5=XS3(5,:);

ppmenu11=XS3_1(1); ppmenu12=XS3_1(2); ppmenu13=XS3_1(3); ppmenu14=XS3_1(4);
ppmenu21=XS3_2(1); ppmenu22=XS3_2(2); ppmenu23=XS3_2(3); ppmenu24=XS3_2(4);
ppmenu31=XS3_3(1); ppmenu32=XS3_3(2); ppmenu33=XS3_3(3); ppmenu34=XS3_3(4);
ppmenu41=XS3_4(1); ppmenu42=XS3_4(2); ppmenu43=XS3_4(3); ppmenu44=XS3_4(4);
ppmenu51=XS3_5(1); ppmenu52=XS3_5(2); ppmenu53=XS3_5(3); ppmenu54=XS3_5(4);
ppmenu61=WS3(1);
ppmenu62=WS3(2);
ppmenu63=WS3(3);
ppmenu64=WS3(4);
templet=0;
close all;
IJA;

end


% --- Executes on button press in pushbutton6.
function pushbutton6_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton6 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
close all;
IJA_demo;

